import * as React from 'react';
import IInputDefaultProps from '../inputDefaultProps';

declare var jQuery: any;

export interface IDatepickerProps extends IInputDefaultProps  {
    selectedValue?: Date,
    format?: string,
    minValue?: Date,
    maxValue?: Date,
    shortYearCutOff?: number,
    showButton?: boolean,
    buttonTitle?: string,
    openOnFocus?: boolean
}

export default class Datepicker extends React.Component<IDatepickerProps, any> {
    
    elInput: HTMLElement;
    apiDatepicker: any;
    
    static defaultProps: Partial<IDatepickerProps> = {
        selectedValue: null,
        format: 'dd/MM/yyyy',
        minValue: new Date(1899, 11, 31),
        maxValue: new Date(2100, 0, 1),
        shortYearCutOff: 30,
        showButton: true,
        buttonTitle: 'Abre o calendário',
        openOnFocus: true
    }
        
    constructor(props: IDatepickerProps){
        super(props);
    }

    componentDidMount() {
        jQuery(this.elInput).tDatePicker(this.props);
        this.apiDatepicker = jQuery(this.elInput).data('tDatePicker');
    }

    componentWillReceiveProps(nextProps: IDatepickerProps) {
        if(this.props.habilitado != nextProps.habilitado) {
            if (nextProps.habilitado === true)
                this.apiDatepicker.enable();
            else
                this.apiDatepicker.disable();
        }
    }

    render() {
        let inputClassName = (this.props.obrigatorio ? "obrigatorio" : "") + " t-input";
        let styles = {
            wrap: {
                width: this.props.tamanho || "auto"
            },
            input: {
                textAlign: "center",
                marginTop: "0px !important"
            },
            icone: {
                marginTop: "3px !important"
            }
        }

        return (
            <div className="t-widget t-datepicker" style={styles.wrap}>
                <div className="t-picker-wrap">
                    <input 
                        ref={(el) => this.elInput = el} 
                        className={inputClassName} 
                        name={this.props.inputName} 
                        style={styles.input} 
                        type="text" />

                    <span className="t-select">
                        <span className="t-icon t-icon-calendar" title="Open the calendar" style={styles.icone}>Open the calendar</span>
                    </span>
                </div>
            </div>
        );
    }
}